@@ -52,6 +52,7 @@
 #include <qcombobox.h>
 #include <qlistbox.h>
 #include <qcursor.h>
+#include <qdir.h>
 
 // User interface
 #include "as_gui.h"             // Main classes
@@ -655,11 +656,8 @@ void Titraqform::setupTable(void)
 
     // Table update signals
     connect(m_pMaintable, SIGNAL(currentChanged(int, int)), this, SLOT(updEdit(int, int)));
-    connect(m_pMaintable, SIGNAL(currentChanged(int, int)), this, SLOT(validateData(int, int)));
     connect(m_pMaintable, SIGNAL(doubleClicked(int, int, int, const QPoint&)), this, SLOT(inplaceEdit(int, int, int, const QPoint&)));
     connect(m_pTablehead, SIGNAL(sizeChange(int, int, int)), this, SLOT(updSizes(int, int, int)));
-    connect(m_pMaintable, SIGNAL(valueChanged(int, int)), this, SLOT(dataChanged(int, int)));
-    connect(m_pMaintable, SIGNAL(valueChanged(int, int)), this, SLOT(validateData(int, int)));
     connect(m_pMaintable, SIGNAL(textEdited(int, int)), this, SLOT(dataChanged(int, int)));
 }
 
@@ -840,7 +838,7 @@ void Titraqform::setupEditlay(void)
 
     // Configure attributes
     m_pAmount->setButtonSymbols(QSpinBox::PlusMinus);
-    m_pAmount->setSuffix(trUtf8(" Minutes"));
+    m_pAmount->setSuffix(trUtf8(" Mins"));
     m_pAmount->setEnabled(false);
 //    m_pAmount->setSpecialValueText(trUtf8("In progress"));
 
@@ -858,8 +856,11 @@ void Titraqform::setupEditlay(void)
         throw Genexcept("Main window task entries creation failed.");
 
     // Populate the stringlist with fresh accounts, taken from filename in prefs
-    QFile Filetemp(m_pPrefs->getString(TITRAQ_PREFACCOUNTS, TITRAQ_PREFACCOUNTS));
-    this->loadAccounts(Filetemp);           // Load account helper method
+    QString Asdir = m_pPrefs->getString(TITRAQ_PREFACCOUNTS, TITRAQ_DEFACCOUNTS);
+    if (Asdir.startsWith(TITRAQ_HOMEDIRTOK))
+        Asdir = QDir::homeDirPath() + Asdir.remove(0, QString(TITRAQ_HOMEDIRTOK).length() - 1);
+    QFile Filetemp(Asdir);
+    this->loadAccounts(Filetemp);   // Load account helper method
 
     // Make the combobox task edit
     m_pTasks = new QComboBox(true, m_pCenframe, "Tasks");
@@ -918,6 +919,23 @@ void Titraqform::setupEditlay(void)
     connect(m_pAmount, SIGNAL(valueChanged(const QString &)), this, SLOT(updateAmount(const QString &)));
     connect(m_pTasks, SIGNAL(textChanged(const QString &)), this, SLOT(updateTask(const QString &)));
     connect(m_pRemark, SIGNAL(textChanged(const QString &)), this, SLOT(updateRemark(const QString &)));
+
+    // Validate data just as it is being entered
+    connect(m_pDateedit, SIGNAL(valueChanged(const QDate &)), this, SLOT(validateData(void)));
+    connect(m_pStarttime, SIGNAL(valueChanged(const QTime &)), this, SLOT(validateData(void)));
+    connect(m_pEndtime, SIGNAL(valueChanged(const QTime &)), this, SLOT(validateData(void)));
+    connect(m_pAmount, SIGNAL(valueChanged(const QString &)), this, SLOT(validateData(void)));
+    connect(m_pTasks, SIGNAL(textChanged(const QString &)), this, SLOT(validateData(void)));
+    connect(m_pRemark, SIGNAL(textChanged(const QString &)), this, SLOT(validateData(void)));
+
+    // Correctly update checksum and revision fields also
+    connect(m_pUseredit, SIGNAL(textChanged(const QString &)), this, SLOT(calcCrc(void)));
+    connect(m_pDateedit, SIGNAL(valueChanged(const QDate &)), this, SLOT(calcCrc(void)));
+    connect(m_pStarttime, SIGNAL(valueChanged(const QTime &)), this, SLOT(calcCrc(void)));
+    connect(m_pEndtime, SIGNAL(valueChanged(const QTime &)), this, SLOT(calcCrc(void)));
+    connect(m_pAmount, SIGNAL(valueChanged(const QString &)), this, SLOT(calcCrc(void)));
+    connect(m_pTasks, SIGNAL(textChanged(const QString &)), this, SLOT(calcCrc(void)));
+    connect(m_pRemark, SIGNAL(textChanged(const QString &)), this, SLOT(calcCrc(void)));
 }
 
 //
