@@ -34,6 +34,7 @@
 #include <qcombobox.h>
 #include <qclipboard.h>
 #include <qmenudata.h>
+#include <qdatastream.h>
 //#include <qregexp.h>
 
 // User interface
@@ -384,16 +385,33 @@ void Titraqform::openDoc(void)
 void Titraqform::saveFile(void)
 {
     QString Fname;
+    QFile Filevents, Filebak;
+    QTextStream Streamevents, Streambak;
+
     try {
         Fname = QString(*this->getFilename());
+
         // First time saves are really just saveAs in disguise
         if (Fname.isEmpty()) {
             this->saveAs();
             return;
         }
-        // Try to open a file for writing to
-        QFile Filetemp(Fname);
-        this->saveData(Filetemp); // Pass to helper method
+
+        Filevents.setName(Fname); // Construct a file to back up and write
+
+        // Make a backup before overwriting
+        if (Filevents.exists()) {
+            Filevents.open(IO_ReadOnly);
+            Filebak.setName(Fname + ".bak");
+            Filebak.open(IO_WriteOnly);
+            Streamevents.setDevice(&Filevents);
+            Streambak.setDevice(&Filebak);
+            Streambak << Streamevents.read();
+            Filevents.close();
+            Filebak.close();
+        }
+
+        this->saveData(Filevents); // Pass to helper method
     }
     catch (Genexcept& Genex) {
         Genex.reportErr();
@@ -432,9 +450,13 @@ void Titraqform::saveAs(void)
                 break;
             }
         }
-        else
+        else {
+            QString Extension = TITRAQ_FEXTENSION;  // Logic to handle
+            if (!Filestring.endsWith(Extension))    // AS file extension
+                Filestring += Extension;            // insertion
             this->setFilename(Filestring);  // Set filename of object first
             this->saveFile();               // Finish by calling the save action
+        }
     }
     else {
         // User did not select a valid file and push okay button
